@@ -69,20 +69,17 @@ void
 greeter_item_ulist_check_show_userlist (void)
 {
 	/*
- 	 * If the browser feature isn't enabled or if there are no users,
-	 * then hide the rectangle used to contain the userlist.  The
-	 * userlist-rect id allows a rectangle to be defined with alpha
+	 * If there are no users, then hide the rectangle used to contain the
+	 * userlist.  This id allows a rectangle to be defined with alpha
 	 * behind the userlist that also goes away when the list is empty.
 	 */
 	if (num_users == 0) {
 		GreeterItemInfo *urinfo = greeter_lookup_id ("userlist-rect");
+		GnomeCanvasItem *item;
 
-		if (user_list != NULL)
-			gtk_widget_hide (user_list);
+		gtk_widget_hide (user_list);
 
 		if (urinfo) {
-			GnomeCanvasItem *item;
-
 			if (urinfo->group_item != NULL)
 				item = GNOME_CANVAS_ITEM (urinfo->group_item);
 			else
@@ -97,9 +94,9 @@ void
 greeter_item_ulist_unset_selected_user (void)
 {
 	GtkTreeSelection *selection;
-        if (user_list != NULL) {
+	if (user_list != NULL) {
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_list));
-		gtk_tree_selection_unselect_all (selection);
+		gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
 	}
 
 	if (selected_user != NULL)
@@ -146,10 +143,8 @@ check_for_displays (void)
 		char **rvec;
 
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (ve_vector_len (rvec) != 3) {
-			g_strfreev (rvec);
+		if (rvec == NULL || ve_vector_len (rvec) != 3)
 			continue;
-		}
 
 		g_hash_table_insert (displays_hash,
 				     g_strdup (rvec[1]),
@@ -313,7 +308,6 @@ greeter_generate_userlist (GtkWidget *tv)
 								       NULL);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (tv), column_two);
 
-		/* Only populate the user list if the browser is turned on */
 		greeter_populate_user_list (tm);
 
 		info = greeter_lookup_id ("userlist");
